import { AbstractDataSource } from './AbstractDataSource.js';
/**
 * Uses your custom api function to request data
 */
export class ApiFunctionDataSource extends AbstractDataSource {
    apiFunction;
    /**
     * Create a new data source to fetch the paginated table data using your custom api function.
     *
     * @param apiFunction the api function which requests data by sending the {@link PaginatedListRequest} and returning a {@link PaginatedListResponse}
     */
    constructor(apiFunction) {
        super();
        this.apiFunction = apiFunction;
    }
    requestData(data) {
        this.apiFunction(data)
            .then((data) => this.updateStatus({ data }))
            .catch((err) => this.updateStatus({ error: err }));
    }
}
