import type { UseQueryOptions } from '@sveltestack/svelte-query';
import type { UseQueryStoreResult } from '@sveltestack/svelte-query/dist/types.js';
import type { Readable } from 'svelte/store';
import type { ApiFunction } from '../types/ApiFunction.js';
import type { FullDataTableConfig } from '../types/DataTableConfig.js';
import type { PaginatedListRequest } from '../types/PaginatedListRequest.js';
import type { PaginatedListResponse } from '../types/PaginatedListResponse.js';
import type { IDataSource } from './IDataSource.js';
import type { QueryObserver } from './QueryObserver.js';
export declare type DataTableUseQueryStoreResult<Data> = UseQueryStoreResult<PaginatedListResponse<Data>, unknown, PaginatedListResponse<Data>, DataTableQueryKey<Data>>;
export declare type DataTableUseQueryOptions<Data> = UseQueryOptions<PaginatedListResponse<Data>, unknown, PaginatedListResponse<Data>, DataTableQueryKey<Data>>;
export declare type DataTableQueryKey<Data> = [key: string, request: PaginatedListRequest<Data>];
/**
 * Uses the Svelte Query library to fetch your paginated table data.
 */
export declare class SvelteQueryDataSource<Data> implements IDataSource<Data> {
    private apiFunction;
    private additionalQueryOptions;
    private readonly dataQuery;
    private readonly dataObserver;
    private queryKey;
    /**
     * Create a new data source to fetch your paginated table data from an api endpoint
     * using Svelte Query in the background to manage requests, caching and more.
     *
     * @param apiFunction the api function which actually fetches your data, passed through to Svelte Query as the [query function](https://sveltequery.vercel.app/guides/query-functions).
     * A query function can be literally any function that returns a promise. The promise that is returned should either resolve the data or throw an error.
     * @param additionalQueryOptions additional options passed to Svelte Query
     *
     * @see {@link https://sveltequery.vercel.app/reference/useQuery}
     */
    constructor(apiFunction: ApiFunction<Data>, additionalQueryOptions?: DataTableUseQueryOptions<Data>);
    getQueryObserver(): Readable<QueryObserver<Data>>;
    init(config: FullDataTableConfig<Data>): void;
    requestData(data: PaginatedListRequest<Data>): void;
    setApiFunction(apiFunction: ApiFunction<Data>): void;
    setEnabled(enabled: boolean): void;
    updateQueryOptions(queryOptions: Partial<DataTableUseQueryOptions<Data>>): void;
    private useNoopQuery;
    private wrapApiFunction;
}
