export class AbstractSearchParser {
    /**
     * Cleans the query by trimming, lowercasing the string and then removing all
     * @param query
     * @protected
     */
    cleanQuery(query) {
        query = query.replace(/\s+/g, ' ').trim();
        return query.toLowerCase();
    }
    /**
     * Splits the raw query into parts/words separated by spaces. Quotation marks can be used to group multiple words into one query part.
     * @param query
     * @protected
     */
    splitQueryParts(query) {
        const queryParts = query.match(/"[^"]*"|[^\s"]+/g);
        if (!queryParts) {
            return [];
        }
        return queryParts.map((p) => p.substring(p.startsWith('"') ? 1 : 0, p.endsWith('"') ? p.length - 1 : p.length));
    }
}
